import QtQuick 2.0
import QtGraphicalEffects 1.0
import Sailfish.Silica 1.0
import Nemo.Configuration 1.0
import org.SfietKonstantin.patchmanager 2.0
import "./presets.js" as PresetData

//import "./components"

Page {
    id: page
    allowedOrientations: Orientation.All
    property bool pmTranslationLoaded: PatchManagerTranslator ? PatchManagerTranslator.installTranslator("patch-icon-filter") : false

    ConfigurationGroup {
        id: conf
        path: "/apps/patchmanager/patch-icon-filter"
        property double brightness: -0.2
        property double contrast: 0.1
        property double desaturation: 0.3
        property bool redshift: false
        property int last_preset
    }

    property bool custom_enabled: false


    SilicaFlickable {
        anchors.fill: parent
        contentHeight: column.height

        VerticalScrollDecorator{}

        PresetModel {
          id: presetModel
          Component.onCompleted: init()
        }

        ContextMenu {
          id: presetMenu
          Repeater {
            model: presetModel
            MenuItem { text: display_name}
            Component.onCompleted: console.debug("repeated: " + count + "from " + model)
          }
        }
        Column {
            id: column
            width: parent.width
            spacing: Theme.paddingMedium

            PageHeader {
                title: qsTr("Filter Settings")
            }

            SectionHeader {
                text: qsTr("Description")
            }

            Label {
                text: qsTr("Adjust the values for the effects to be applied to the icons.  " +
                "Once the patch is applied, changes here will take effect immediately."
                )
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                width: parent.width - 2*x
                x: Theme.horizontalPageMargin
                font.pixelSize: Theme.fontSizeSmall
            }

            Item {
              width: parent.width - 2*x
              height: iconRowPlain.height
              x: Theme.horizontalPageMargin
              Row {
                id: iconRowPlain
                spacing: Theme.paddingLarge
                anchors.horizontalCenter: parent.horizontalCenter
                height: Theme.iconSizeLarge
                Image { source: "image://theme/icon-launcher-gallery"}
                Image { source: "image://theme/icon-launcher-email"}
                Image { source: "image://theme/icon-launcher-messaging"}
                Image { source: "image://theme/icon-launcher-calendar"}
              }
            }
            Item {
              width: parent.width - 2*x
              height: iconRow.height
              x: Theme.horizontalPageMargin
              anchors.horizontalCenter: parent.horizontalCenter
              Row {
                id: iconRow
                spacing: Theme.paddingLarge
                anchors.horizontalCenter: parent.horizontalCenter
                height: Theme.iconSizeLarge
                Image { source: "image://theme/icon-launcher-gallery"}
                Image { source: "image://theme/icon-launcher-email"}
                Image { source: "image://theme/icon-launcher-messaging"}
                Image { source: "image://theme/icon-launcher-calendar"}
              }
              BrightnessContrast {
                  id: iconRowEff1
                  source: iconRow
                  anchors.centerIn: source
                  height: source.height
                  width: source.width

                  // hide to daisy-chain with next effect
                  visible: false
                  cached: visible

                  brightness: conf.brightness
                  contrast: conf.contrast
              }

              Desaturate {
                  id: iconRowEff2
                  source: iconRowEff1
                  anchors.centerIn: source
                  height: source.height
                  width: source.width
                  // hide to daisy-chain with next effect
                  visible: !iconRowEff3.visible
                  cached: visible
                  desaturation: conf.desaturation
              }
              ColorOverlay {
                  id: iconRowEff3
                  source: iconRowEff2
                  anchors.centerIn: source
                  height: source.height
                  width: source.width
                  cached: visible
                  visible: conf.redshift

                  // slight red tint (night light)
                  color: "#20ff0000"
              }
            }

            SectionHeader {
                text: qsTr("Presets")
            }

            Label {
              text: qsTr("Select predefined sets, or \"%1\" to customize").arg(qsTr("User Defined"))
              wrapMode: Text.WrapAtWordBoundaryOrAnywhere
              width: parent.width - 2*x
              x: Theme.horizontalPageMargin
              font.pixelSize: Theme.fontSizeSmall
            }
            ComboBox {
              id: selector
              //width: parent.width
              anchors.horizontalCenter: parent.horizontalCenter
              label: qsTr("Preset" +":")
              description: presetModel.get(currentIndex).description ? presetModel.get(currentIndex).description : ""
              menu: presetMenu

              currentIndex: conf.last_preset ? conf.last_preset : presetModel.default_idx
              Component.onCompleted: {
                     presetModel.init();
                    currentIndex = conf.last_preset ? conf.last_preset : presetModel.default_idx
              }
              onCurrentIndexChanged: {
                if (!currentItem) return;
                if (presetModel.get(currentIndex).name !== "custom") {
                  page.custom_enabled = false;
                  conf.brightness   = presetModel.get(currentIndex).brightness;
                  conf.contrast     = presetModel.get(currentIndex).contrast;
                  conf.desaturation = presetModel.get(currentIndex).desaturation;
                  conf.redshift     = presetModel.get(currentIndex).redshift;
                  conf.sync();
                } else {
                  page.custom_enabled = true;
                }
                conf.last_preset  = selector.currentIndex;
              }
            }
            Separator { width: parent.width; horizontalAlignment: Qt.AlignRight; color: Theme.primaryColor }

            SectionHeader {
                text: qsTr("Brightness") + "/" + qsTr("Contrast")
            }

            Slider {
              enabled:  page.custom_enabled; opacity: enabled? 1.0 : Theme.opacityLow
              Behavior on opacity { FadeAnimation {} }
              width: parent.width
              minimumValue: -0.8
              maximumValue: 0.8
              stepSize: 0.01
              value: conf.brightness
              valueText: value.toPrecision(2)
              handleVisible: true
              label: qsTr("Brightness")
              onReleased:  { conf.setValue("brightness", sliderValue.toPrecision(3)) }
            }

            Slider {
              enabled:  page.custom_enabled; opacity: enabled? 1.0 : Theme.opacityLow
              Behavior on opacity { FadeAnimation {} }
              width: parent.width
              minimumValue: -0.8
              maximumValue: 0.8
              stepSize: 0.01
              value: conf.contrast
              valueText: value.toPrecision(2)
              handleVisible: true
              label: qsTr("Contrast")
              onReleased:  { conf.setValue("contrast", sliderValue.toPrecision(3)) }
            }

            SectionHeader {
                text: qsTr("Desaturation")
            }

            Slider {
              enabled:  page.custom_enabled; opacity: enabled? 1.0 : Theme.opacityLow
              Behavior on opacity { FadeAnimation {} }
              width: parent.width
              minimumValue: 0.0
              maximumValue: 1.0
              stepSize: 0.01
              value: conf.desaturation
              valueText: value.toPrecision(2)
              handleVisible: true
              label: qsTr("Desaturation")
              onReleased:  { conf.setValue("desaturation", sliderValue.toPrecision(3)) }
            }

            SectionHeader {
                text: qsTr("Color Overlay")
            }

            TextSwitch {
              //enabled:  page.custom_enabled
              enabled: false
              opacity: enabled? 1.0 : Theme.opacityLow
              Behavior on opacity { FadeAnimation {} }
              width: parent.width - 2*x
              x: Theme.horizontalPageMargin
              text: qsTr("Enable Redshift (Night Mode)")
              checked: conf.redshift
              onCheckedChanged:  { conf.setValue("redshift", checked) }
            }

        }
    }

}

// vim: expandtab ts=4 st=4 filetype=javascript
